@@ -1,10 +1,9 @@
 package HTML::Lint::Error;
 
-use warnings;
 use strict;
 
-use parent 'Exporter';
-
+use base 'Exporter';
+our @EXPORT = ();
 our @EXPORT_OK = qw( STRUCTURE HELPER FLUFF );
 our %EXPORT_TAGS = ( types => [@EXPORT_OK] );
 
@@ -54,10 +53,9 @@ This is usually something like an unknown attribute on a tag.
 
 =cut
 
-use constant CONFIG     => 1;
-use constant STRUCTURE  => 2;
-use constant HELPER     => 3;
-use constant FLUFF      => 4;
+use constant STRUCTURE  => 1;
+use constant HELPER     => 2;
+use constant FLUFF      => 3;
 
 =head2 new()
 
@@ -66,23 +64,23 @@ Create an object.  It's not very exciting.
 =cut
 
 sub new {
-    my $class    = shift;
+    my $class = shift;
 
-    my $file     = shift;
-    my $line     = shift;
-    my $column   = shift;
-    my $errcode  = shift;
+    my $file = shift;
+    my $line = shift;
+    my $column = shift;
+    my $errcode = shift;
     my @errparms = @_;
 
     # Add an element that says what tag caused the error (B, TR, etc)
     # so that we can match 'em up down the road.
     my $self  = {
-        _file    => $file,
-        _line    => $line,
-        _column  => $column,
+        _file => $file,
+        _line => $line,
+        _column => $column,
         _errcode => $errcode,
         _errtext => undef,
-        _type    => undef,
+        _type => undef,
     };
 
     bless $self, $class;
@@ -100,23 +98,19 @@ sub _expand_error {
     my $specs = $errors{$errcode};
     my $str;
     if ( $specs ) {
-        ($str, $self->{_type}) = @{$specs};
+        ($str, $self->{_type}) = @$specs;
     }
     else {
         $str = "Unknown code: $errcode";
     }
 
-    if ( defined $str ) {
-        while ( @_ ) {
-            my $var = shift;
-            my $val = shift;
-            $str =~ s/\$\{$var\}/$val/g;
-        }
+    while ( @_ ) {
+        my $var = shift;
+        my $val = shift;
+        $str =~ s/\$\{$var\}/$val/g;
     }
 
     $self->{_errtext} = $str;
-
-    return;
 }
 
 =head2 is_type( $type1 [, $type2 ] )
@@ -170,14 +164,13 @@ sub where {
     if ( not ref $_[0] ) {
         $line = shift;
         $col = shift;
-    }
-    else {
+    } else {
         my $self = shift;
         $line = $self->line;
         $col = $self->column;
     }
     $col ||= 0;
-    return sprintf( '(%s:%s)', $line, $col + 1 );
+    return sprintf( "(%s:%s)", $line, $col + 1 );
 }
 
 =head2 as_string()
@@ -189,7 +182,7 @@ Returns a nicely-formatted string for printing out to stdout or some similar use
 sub as_string {
     my $self = shift;
 
-    return sprintf( '%s %s %s', $self->file, $self->where, $self->errtext );
+    return sprintf( "%s %s %s", $self->file, $self->where, $self->errtext );
 }
 
 =head2 file()
@@ -218,136 +211,21 @@ Type of the error
 
 =cut
 
-sub file        { my $self = shift; return $self->{_file}    || '' }
-sub line        { my $self = shift; return $self->{_line}    || '' }
-sub column      { my $self = shift; return $self->{_column}  || '' }
-sub errcode     { my $self = shift; return $self->{_errcode} || '' }
-sub errtext     { my $self = shift; return $self->{_errtext} || '' }
-sub type        { my $self = shift; return $self->{_type}    || '' }
+sub file        { my $self = shift; return $self->{_file}       || '' }
+sub line        { my $self = shift; return $self->{_line}       || '' }
+sub column      { my $self = shift; return $self->{_column}     || '' }
+sub errcode     { my $self = shift; return $self->{_errcode}    || '' }
+sub errtext     { my $self = shift; return $self->{_errtext}    || '' }
+sub type        { my $self = shift; return $self->{_type}       || '' }
 
 
-=head1 POSSIBLE ERRORS
+=head1 TODO
 
-Each possible error in HTML::Lint has a code.  These codes are used
-to identify each error for when you need to turn off error checking
-for a specific error.
+None, other than incorporating more errors, as driven by HTML::Lint.
 
-=cut
+=head1 LICENSE
 
-%errors = ( ## no critic ( ValuesAndExpressions::RequireInterpolationOfMetachars )
-    'api-parse-not-called'     => ['The parse() method has not been called on this file.', CONFIG],
-    'api-eof-not-called'       => ['The eof() method has not been called on this file.', CONFIG],
-    'config-unknown-directive' => ['Unknown directive "${directive}"', CONFIG],
-    'config-unknown-value'     => ['Unknown value "${value}" for ${directive} directive', CONFIG],
-
-    'elem-empty-but-closed'    => ['<${tag}> is not a container -- </${tag}> is not allowed', STRUCTURE],
-    'elem-img-alt-missing'     => ['<img src="${src}"> does not have ALT text defined', HELPER],
-    'elem-img-sizes-missing'   => ['<img src="${src}"> tag has no HEIGHT and WIDTH attributes', HELPER],
-    'elem-input-alt-missing'   => ['<input name="${name}" type="image"> does not have non-blank ALT text defined', HELPER],
-    'elem-nonrepeatable'       => ['<${tag}> is not repeatable, but already appeared at ${where}', STRUCTURE],
-    'elem-unclosed'            => ['<${tag}> at ${where} is never closed', STRUCTURE],
-    'elem-unknown'             => ['Unknown element <${tag}>', STRUCTURE],
-    'elem-unopened'            => ['</${tag}> with no opening <${tag}>', STRUCTURE],
-
-    'doc-tag-required'         => ['<${tag}> tag is required', STRUCTURE],
-
-    'attr-repeated'            => ['${attr} attribute in <${tag}> is repeated', STRUCTURE],
-    'attr-unknown'             => ['Unknown attribute "${attr}" for tag <${tag}>', FLUFF],
-    'attr-invalid-entity'      => ['Entity ${entity} is invalid', STRUCTURE],
-    'attr-unclosed-entity'     => ['Entity ${entity} is missing its closing semicolon', STRUCTURE],
-    'attr-unknown-entity'      => ['Entity ${entity} is unknown', STRUCTURE],
-    'attr-use-entity'          => ['Character "${char}" should be written as ${entity}', STRUCTURE],
-
-    'text-invalid-entity'      => ['Entity ${entity} is invalid', STRUCTURE],
-    'text-unclosed-entity'     => ['Entity ${entity} is missing its closing semicolon', STRUCTURE],
-    'text-unknown-entity'      => ['Entity ${entity} is unknown', STRUCTURE],
-    'text-use-entity'          => ['Character "${char}" should be written as ${entity}', STRUCTURE],
-);
-
-=head2 api-parse-not-called
-
-You called the C<errors()> method before calling C<parse()> and C<eof()>.
-
-=head2 api-eof-not-called
-
-You called the C<errors()> method before calling C<eof()>.
-
-=head2 config-unknown-directive
-
-Unknown directive "DIRECTIVE"
-
-You specified a directive in a comment for HTML::Lint that it didn't recognize.
-
-=head2 config-unknown-value
-
-Unknown value "VALUE" for DIRECTIVE directive
-
-Directive values can only be "on", "off", "yes", "no", "true", "false", "0" and "1".
-
-=head2 elem-unknown
-
-HTML::Lint doesn't know recognize the tag.
-
-=head2 elem-unopened
-
-C<< </tag> >> with no opening C<< <tag> >>.
-
-=head2 elem-unclosed
-
-C<< <tag> >> at WHERE is never closed.
-
-=head2 elem-empty-but-closed
-
-C<< <tag> >> is not a container -- C<< </tag> >> is not allowed.
-
-=head2 elem-img-alt-missing
-
-C<< <img src="FILENAME.PNG"> >> does not have ALT text defined.
-
-=head2 elem-img-sizes-missing
-
-C<< <img src="FILENAME.PNG"> >> tag has no HEIGHT and WIDTH attributes.
-
-=head2 elem-nonrepeatable
-
-C<< <tag> >> is not repeatable, but already appeared at WHERE.
-
-=head2 doc-tag-required
-
-C<< <tag> >> tag is required.
-
-=head2 attr-repeated
-
-ATTR attribute in C<< <tag> >> is repeated.
-
-=head2 attr-unknown
-
-Unknown attribute "ATTR" for tag C<< <tag> >>.
-
-=head2 text-invalid-entity
-
-Entity ENTITY is invalid
-
-=head2 text-unclosed-entity
-
-Entity ENTITY is missing its closing semicolon
-
-=head2 text-unknown-entity
-
-Entity ENTITY is unknown
-
-=head2 text-use-entity
-
-Character "CHAR" should be written as ENTITY
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2005-2017 Andy Lester.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License v2.0.
-
-http://www.opensource.org/licenses/Artistic-2.0
+This code may be distributed under the same terms as Perl itself.
 
 Please note that these modules are not products of or supported by the
 employers of the various contributors to the code.
@@ -358,6 +236,28 @@ Andy Lester, C<andy at petdance.com>
 
 =cut
 
+
+# Errors that are commented out have not yet been implemented.
+
+# Generic element stuff
+%errors = (
+    'elem-unknown' =>           ['Unknown element <${tag}>', STRUCTURE],
+    'elem-unopened' =>          ['</${tag}> with no opening <${tag}>', STRUCTURE],
+    'elem-unclosed' =>          ['<${tag}> at ${where} is never closed', STRUCTURE],
+    'elem-empty-but-closed' =>  ['<${tag}> is not a container -- </${tag}> is not allowed', STRUCTURE],
+
+    'elem-img-sizes-missing' => ['<IMG SRC="${src}"> tag has no HEIGHT and WIDTH attributes.', HELPER],
+    'elem-img-alt-missing' =>   ['<IMG SRC="${src}"> does not have ALT text defined', HELPER],
+    'elem-nonrepeatable' =>     ['<${tag}> is not repeatable, but already appeared at ${where}', STRUCTURE],
+
+    'doc-tag-required' =>       ['<${tag}> tag is required', STRUCTURE],
+
+    'attr-repeated' =>          ['${attr} attribute in <${tag}> is repeated', STRUCTURE],
+    'attr-unknown' =>           ['Unknown attribute "${attr}" for tag <${tag}>', FLUFF],
+
+    'text-use-entity' =>        ['Invalid character ${char} should be written as ${entity}', STRUCTURE],
+);
+
 1; # happy
 
 __DATA__
